@@ -44,7 +44,7 @@ const (
 	azureAuthKeyEnvName             = "AZURE_AUTH_LOCATION"
 )
 
-var _ = Describe("Vulnerabilty", func() {
+var _ = Describe("Vulnerability", func() {
 
 	BeforeSuite(func() {
 		terrascanBinaryPath = helper.GetTerrascanBinaryPath()
@@ -60,7 +60,7 @@ var _ = Describe("Vulnerabilty", func() {
 		errWriter = nil
 	})
 
-	Describe("resource with conatiner images to be scanned for vulnerabilities", func() {
+	Describe("resource with container images to be scanned for vulnerabilities", func() {
 		resourceVulnerabilityIacRelPath := filepath.Join(iacRootRelPath, "resource_for_vulnerability_scan")
 		Context("resource with aws ecr registry image used which has vulnerabilities", func() {
 			iacDir := filepath.Join(resourceVulnerabilityIacRelPath, "aws_ecr_registry_used_in_resource")
